Analysing ensembles
======================

If we have output at one location from various runs, for example for future climate scenarios, it can be useful to analyse the mean, max, and min thereof.
Also, one may want to vizualize it.
Besides, it is also possible to determine the long-term monthly average and plot it.

.. autoclass:: sim_data.ensembles
    :members:

    
